@@ -101,8 +101,7 @@ pub(super) fn dispatch(repo: &gix::Repository, matches: &clap::ArgMatches) -> Re
         stdout.set_color(&color_spec)?;
 
         let description = config
-            .plumbing()
-            .string("branch", Some(branchname.into()), "description")
+            .string_by("branch", Some(branchname.into()), "description")
             .unwrap_or_default();
         if description.is_empty() {
             writeln!(stdout)?;
