@@ -4,13 +4,13 @@
 
 use winnow::{
     combinator::{alt, opt, separated_pair},
-    PResult, Parser,
+    ModalResult, Parser,
 };
 
 use super::patch_locator;
 use crate::patch::{PatchRange, PatchRangeBounds};
 
-pub(in super::super) fn patch_range(input: &mut &str) -> PResult<PatchRange> {
+pub(in super::super) fn patch_range(input: &mut &str) -> ModalResult<PatchRange> {
     alt((
         patch_range_bounds.map(PatchRange::Range),
         patch_locator.map(PatchRange::Single),
@@ -18,7 +18,7 @@ pub(in super::super) fn patch_range(input: &mut &str) -> PResult<PatchRange> {
     .parse_next(input)
 }
 
-pub(super) fn patch_range_bounds(input: &mut &str) -> PResult<PatchRangeBounds> {
+pub(super) fn patch_range_bounds(input: &mut &str) -> ModalResult<PatchRangeBounds> {
     separated_pair(opt(patch_locator), "..", opt(patch_locator))
         .map(|(begin, end)| PatchRangeBounds { begin, end })
         .parse_next(input)
