@@ -7,7 +7,7 @@ mod revisions;
 
 use std::str::FromStr;
 
-use nom::combinator::opt;
+use winnow::{combinator::opt, Parser};
 
 use super::numbers::unsigned_int;
 use crate::patch::{PatchName, PatchOffsets};
@@ -22,13 +22,16 @@ fn offsets(s: &str) -> PatchOffsets {
 
 #[test]
 fn number_stuff() {
-    assert_eq!(opt(unsigned_int)(""), Ok(("", None)));
+    assert_eq!(opt(unsigned_int).parse_peek(""), Ok(("", None)));
     assert_eq!(
-        opt(unsigned_int)("0000000000000000000000017"),
+        opt(unsigned_int).parse_peek("0000000000000000000000017"),
         Ok(("", Some(17)))
     );
-    assert_eq!(opt(unsigned_int)("1234"), Ok(("", Some(1234))));
-    assert_eq!(opt(unsigned_int)("-1234"), Ok(("-1234", None)));
-    assert_eq!(opt(unsigned_int)("1234abc"), Ok(("abc", Some(1234))));
-    assert_eq!(opt(unsigned_int)("abc"), Ok(("abc", None)));
+    assert_eq!(opt(unsigned_int).parse_peek("1234"), Ok(("", Some(1234))));
+    assert_eq!(opt(unsigned_int).parse_peek("-1234"), Ok(("-1234", None)));
+    assert_eq!(
+        opt(unsigned_int).parse_peek("1234abc"),
+        Ok(("abc", Some(1234)))
+    );
+    assert_eq!(opt(unsigned_int).parse_peek("abc"), Ok(("abc", None)));
 }
