@@ -238,8 +238,7 @@ impl<'repo> Stack<'repo> {
     /// Check whether the stack is marked as protected in the config.
     pub(crate) fn is_protected(&self, config: &gix::config::Snapshot) -> bool {
         config
-            .plumbing()
-            .boolean(
+            .boolean_by(
                 "branch",
                 Some(format!("{}.stgit", self.branch_name).as_str().into()),
                 "protect",
@@ -257,10 +256,15 @@ impl<'repo> Stack<'repo> {
         let mut local_config_file = self.repo.local_config_file()?;
 
         if protect {
-            local_config_file.set_raw_value(section, Some(subsection.into()), "protect", "true")?;
+            local_config_file.set_raw_value_by(
+                section,
+                Some(subsection.into()),
+                "protect",
+                "true",
+            )?;
         } else {
             if let Ok(mut value) =
-                local_config_file.raw_value_mut(section, Some(subsection.into()), "protect")
+                local_config_file.raw_value_mut_by(section, Some(subsection.into()), "protect")
             {
                 value.delete();
             }
@@ -305,9 +309,7 @@ impl<'repo> Stack<'repo> {
         let prev_state_commit = self
             .repo
             .find_reference(&self.stack_refname)?
-            .into_fully_peeled_id()?
-            .object()?
-            .try_into_commit()?;
+            .peel_to_commit()?;
         let prev_state_commit_id = prev_state_commit.id;
         let state = self
             .state
@@ -330,9 +332,9 @@ impl<'repo> Stack<'repo> {
                     message: reflog_msg.into(),
                 },
                 expected: gix::refs::transaction::PreviousValue::ExistingMustMatch(
-                    gix::refs::Target::Peeled(prev_state_commit_id),
+                    gix::refs::Target::Object(prev_state_commit_id),
                 ),
-                new: gix::refs::Target::Peeled(state_commit_id),
+                new: gix::refs::Target::Object(state_commit_id),
             },
             name: gix::refs::FullName::try_from(self.stack_refname.as_str())?,
             deref: false,
@@ -491,7 +493,7 @@ fn ensure_patch_refs(repo: &gix::Repository, branch_name: &str, state: &StackSta
                                 expected: gix::refs::transaction::PreviousValue::ExistingMustMatch(
                                     existing_ref.target().into_owned(),
                                 ),
-                                new: gix::refs::Target::Peeled(patchdesc.commit.id),
+                                new: gix::refs::Target::Object(patchdesc.commit.id),
                             },
                             name: existing_ref.name().into(),
                             deref: false,
@@ -522,7 +524,7 @@ fn ensure_patch_refs(repo: &gix::Repository, branch_name: &str, state: &StackSta
                     message: "fixup missing patch ref".into(),
                 },
                 expected: gix::refs::transaction::PreviousValue::MustNotExist,
-                new: gix::refs::Target::Peeled(patchdesc.commit.id),
+                new: gix::refs::Target::Object(patchdesc.commit.id),
             },
             name: gix::refs::FullName::try_from(get_patch_refname(
                 branch_name,
