@@ -8,8 +8,8 @@ test_expect_success 'Create five applied and three unapplied patches' '
     for i in 0 1 2 3 4 5 6 7; do
         echo $i >>foo &&
         stg add foo &&
-        git commit -m p$i
-    done
+        git commit -m p$i || return 1
+    done &&
     stg uncommit -n 8 &&
     stg pop -n 3
 '
