@@ -285,12 +285,12 @@ test_expect_success 'Import with author options' '
     git checkout jabberwocky.txt &&
     stg import --authname "Some Author" \
                --authemail "some@example.com" \
-               --authdate 2005-04-07T22:13:13 \
+               --authdate "2005-04-07T22:13:13-05:00" \
                --stripname \
                -C5 \
                some.patch &&
     stg show | grep -e "Author: Some Author <some@example.com>" &&
-    stg show | grep -E "Date: +Thu Apr 7 22:13:13 2005 \+0000" &&
+    stg show | grep -E "Date: +Thu Apr 7 22:13:13 2005 -0500" &&
     stg delete --top
 '
 
@@ -366,6 +366,16 @@ test_expect_success 'Import series from stdin' '
     stg delete --top
 '
 
+test_expect_success 'Import patch that does not apply cleanly with --reject' '
+    conflict stg import --reject "$TEST_DIRECTORY"/t1800/diff-with-rejects 2>err &&
+    git log -1 --pretty=format:%b >body &&
+    test_when_finished "rm foo.txt.rej err body" &&
+    test "$(echo $(stg top))" = "diff-with-rejects" &&
+    test_line_count = 0 body &&
+    stg reset --hard &&
+    stg delete --top
+'
+
 test_expect_success STG_IMPORT_URL 'Attempt url' '
     general_error stg import --url 2>err &&
     grep -e "required arguments were not provided" err
