@@ -6,16 +6,16 @@ test_description='Test "stg hide" and "stg unhide"'
 
 test_expect_success 'Attempt hide on uninitialized stack' '
     command_error stg hide foo 2>err &&
-    grep "error: Patch \`foo\` does not exist" err &&
+    grep "error: patch \`foo\` does not exist" err &&
     command_error stg unhide foo 2>err &&
-    grep "error: Patch \`foo\` does not exist" err
+    grep "error: patch \`foo\` does not exist" err
 '
 
 test_expect_success 'Attempt too few arguments' '
     general_error stg hide   2>err &&
-    grep -e "error: The following required arguments were not provided:" err &&
+    grep -e "error: the following required arguments were not provided:" err &&
     general_error stg unhide 2>err &&
-    grep -e "error: The following required arguments were not provided:" err
+    grep -e "error: the following required arguments were not provided:" err
 '
 
 test_expect_success 'Add some patches' '
@@ -31,7 +31,7 @@ test_expect_success 'Hide already hidden patch' '
 
 test_expect_success 'Attempt unhide non-hidden patch' '
     command_error stg unhide p0 2>err &&
-    grep -e "Patch \`p0\` is not hidden" err
+    grep -e "patch \`p0\` is not hidden" err
 '
 
 test_expect_success 'Unhide hidden patch' '
