@@ -14,10 +14,11 @@ test_expect_success 'init branch with nbsp in name' '
 '
 
 test_expect_success 'new patch with nbsp in name' '
-    echo "hello" > foo.txt &&
+    echo "hello" >foo.txt &&
     git add foo.txt &&
     stg new "a${nbsp}patch" &&
-    stg refresh
+    stg refresh &&
+    test "$(echo $(stg series --noprefix))" = "a${nbsp}patch"
 '
 
 test_expect_success 'patch with nbsp in description' '
